@@ -1,9 +1,10 @@
+# frozen_string_literal: true
+
 module Tmuxinator
   class Config
     LOCAL_DEFAULTS = ["./.tmuxinator.yml", "./.tmuxinator.yaml"].freeze
-    NO_LOCAL_FILE_MSG =
-      "Project file at ./.tmuxinator.yml doesn't exist.".freeze
-    NO_PROJECT_FOUND_MSG = "Project could not be found.".freeze
+    NO_LOCAL_FILE_MSG = "Project file at ./.tmuxinator.yml doesn't exist."
+    NO_PROJECT_FOUND_MSG = "Project could not be found."
     TMUX_MASTER_VERSION = Float::INFINITY
 
     class << self
@@ -12,6 +13,7 @@ module Tmuxinator
         return environment if environment?
         return xdg if xdg?
         return home if home?
+
         # No project directory specified or existent, default to XDG:
         FileUtils::mkdir_p(xdg)
         xdg
@@ -40,6 +42,7 @@ module Tmuxinator
       def environment
         environment = ENV["TMUXINATOR_CONFIG"]
         return "" if environment.to_s.empty? # variable is unset (nil) or blank
+
         FileUtils::mkdir_p(environment) unless File.directory?(environment)
         environment
       end
@@ -48,6 +51,10 @@ module Tmuxinator
         File.directory?(environment)
       end
 
+      def default_or_sample
+        default? ? default : sample
+      end
+
       def sample
         asset_path "sample.yml"
       end
@@ -57,7 +64,7 @@ module Tmuxinator
       end
 
       def default?
-        exists?(name: "default")
+        exist?(name: "default")
       end
 
       def version
@@ -76,9 +83,10 @@ module Tmuxinator
         version && version < 1.8 ? "default-path" : "-c"
       end
 
-      def exists?(name: nil, path: nil)
+      def exist?(name: nil, path: nil)
         return File.exist?(path) if path
         return File.exist?(project(name)) if name
+
         false
       end
 
@@ -140,21 +148,24 @@ module Tmuxinator
 
       def valid_project_config?(project_config)
         return false unless project_config
-        unless exists?(path: project_config)
+        unless exist?(path: project_config)
           raise "Project config (#{project_config}) doesn't exist."
         end
+
         true
       end
 
       def valid_local_project?(name)
         return false if name
         raise NO_LOCAL_FILE_MSG unless local?
+
         true
       end
 
       def valid_standard_project?(name)
         return false unless name
-        raise "Project #{name} doesn't exist." unless exists?(name: name)
+        raise "Project #{name} doesn't exist." unless exist?(name: name)
+
         true
       end
 
@@ -193,6 +204,7 @@ module Tmuxinator
       # recursively searching 'directory'
       def project_in(directory, name)
         return nil if String(directory).empty?
+
         projects = Dir.glob("#{directory}/**/*.{yml,yaml}").sort
         projects.detect { |project| File.basename(project, ".*") == name }
       end
